summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/config.h10
-rw-r--r--include/modules.h6
2 files changed, 12 insertions, 4 deletions
diff --git a/include/modules.h b/include/modules.h
index be5c14447..ac74a7372 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -498,10 +498,10 @@ class CoreExport Module : public Extensible
*/
virtual EventReturn OnPreChanExpire(ChannelInfo *ci) { return EVENT_CONTINUE; }
- /** Called when a channel expires
- * @param chname The channel name
+ /** Called before a channel expires
+ * @param ci The channel
*/
- virtual void OnChanExpire(const Anope::string &chname) { }
+ virtual void OnChanExpire(ChannelInfo *ci) { }
/** Called before Anope connects to its uplink
* @param u The uplink we're going to connect to
diff --git a/include/config.h b/include/config.h
index 0dfd70d9d..aef620b3c 100644
--- a/include/config.h
+++ b/include/config.h
@@ -593,8 +593,12 @@ class CoreExport ServerConfig
time_t NSRegDelay;
/* Time before the registering mail will be resent */
time_t NSResendDelay;
/* How long before nicks expir */
time_t NSExpire;
+ /* How long before suspended nicks expire */
+ time_t NSSuspendExpire;
+ /* How long before forbidden nicks expire */
+ time_t NSForbidExpire;
/* Time before NickRequests expire */
time_t NSRExpire;
/* Force email when registering */
@@ -630,6 +634,10 @@ class CoreExport ServerConfig
unsigned CSMaxReg;
/* Time before a channel expires */
time_t CSExpire;
+ /* How long before suspended channels expire */
+ time_t CSSuspendExpire;
+ /* How long before forbidden channels expire */
+ time_t CSForbidExpire;
/* Default ban type to use for channels */
int CSDefBantype;
/* Max number of entries allowed on channel access lists */
@@ -593,8 +593,12 @@ class CoreExport ServerConfig
/* Time before the registering mail will be resent */
time_t NSResendDelay;
- /* How long before nicks expir */
+ /* How long before nicks expire */
time_t NSExpire;